@@ -59,6 +59,15 @@ class PythonUtil:
         """
         return inspect.signature(_callable).parameters
 
+    @staticmethod
+    def removeunwantedparams(_callable: callable, **kwargs) -> dict:
+        params_of_method = PythonUtil.paramsofmethod(_callable).keys()
+        new_params = dict()
+        for key, value in kwargs.items():
+            if key in params_of_method:
+                new_params.setdefault(key, value)
+        return new_params
+
     @staticmethod
     def getpackageversion(dist: str) -> str:
         try:
@@ -67,13 +76,14 @@ class PythonUtil:
             return e.__str__()
 
     @staticmethod
-    def metaclass(_for: Literal['interface', 'singleton']):
+    def metaclass(_for: Literal['interface', 'singleton', 'attribute_holder']):
         """
         Example Usage:
          class Inter(metaclass=metaclass('singleton'):
              pass
         """
-        _meta_class = {'interface': Meta.interface, 'singleton': Meta.singleton}
+        _meta_class = {'interface': Meta.interface, 'singleton': Meta.singleton,
+                       'attribute_holder': Meta.attribute_holder}
         return _meta_class.get(_for)
 
     @staticmethod
